@@ -7,14 +7,15 @@ financial facts with AI-ready features.
 
 from datetime import date, datetime
 from typing import List, Dict, Optional, Union, Callable, Any, TYPE_CHECKING
+from collections import defaultdict
 import pandas as pd
+import re
 from rich.box import SIMPLE_HEAVY, SIMPLE
 from rich.console import Group
 from rich.padding import Padding
 from rich.panel import Panel
 from rich.table import Table
 from rich.text import Text
-from collections import defaultdict
 
 from edgar.entity.models import FinancialFact, DataQuality
 
@@ -90,6 +91,54 @@ class FactQuery:
             self._filters.append(lambda f: f.label == label)
         return self
     
+    def by_text(self, pattern: str) -> 'FactQuery':
+        """
+        Search across concept names, labels, and other text fields for a pattern.
+        
+        This is a flexible search that looks for the pattern in all relevant text fields
+        of the financial facts using case-insensitive regex matching.
+        
+        Args:
+            pattern: Pattern to search for in various text fields (supports regex)
+            
+        Returns:
+            Self for method chaining
+            
+        Example:
+            # Find all revenue-related facts
+            facts.query().by_text("revenue|sales")
+            
+            # Find facts with "cash" in any text field
+            facts.query().by_text("cash")
+        """
+        regex = re.compile(pattern, re.IGNORECASE)
+        
+        def text_filter(fact):
+            # Search in concept name
+            if fact.concept and regex.search(fact.concept):
+                return True
+            
+            # Search in label
+            if fact.label and regex.search(fact.label):
+                return True
+            
+            # Search in taxonomy (namespace)
+            if fact.taxonomy and regex.search(fact.taxonomy):
+                return True
+            
+            # Search in business context if available
+            if hasattr(fact, 'business_context') and fact.business_context and regex.search(fact.business_context):
+                return True
+            
+            # Search in statement type if available
+            if fact.statement_type and regex.search(fact.statement_type):
+                return True
+                
+            return False
+        
+        self._filters.append(text_filter)
+        return self
+    
     # Time-based filtering
     def by_fiscal_year(self, year: int) -> 'FactQuery':
         """
@@ -149,20 +198,56 @@ class FactQuery:
         self._filters.append(matches_period_length)
         return self
     
-    def date_range(self, start: date, end: date) -> 'FactQuery':
+    def date_range(self, start: Union[date, str, None] = None, end: Union[date, str, None] = None) -> 'FactQuery':
         """
         Filter by date range.
         
         Args:
-            start: Start date (inclusive)
-            end: End date (inclusive)
+            start: Start date (inclusive). Can be a date object or string in 'YYYY-MM-DD' format
+            end: End date (inclusive). Can be a date object or string in 'YYYY-MM-DD' format
             
         Returns:
             Self for method chaining
+            
+        Raises:
+            ValueError: If neither start nor end is provided, or if date string format is invalid
         """
-        self._filters.append(
-            lambda f: f.period_end and start <= f.period_end <= end
-        )
+        if start is None and end is None:
+            raise ValueError("At least one of start or end date must be provided")
+        
+        # Parse string dates to date objects
+        def parse_date(date_value: Union[date, str, None]) -> Optional[date]:
+            if date_value is None:
+                return None
+            if isinstance(date_value, date):
+                return date_value
+            if isinstance(date_value, str):
+                try:
+                    return datetime.strptime(date_value, '%Y-%m-%d').date()
+                except ValueError:
+                    raise ValueError(f"Invalid date format '{date_value}'. Expected 'YYYY-MM-DD'")
+            raise ValueError(f"Invalid date type: {type(date_value)}. Expected date object or string")
+        
+        parsed_start = parse_date(start)
+        parsed_end = parse_date(end)
+        
+        # Create filter based on provided dates
+        if parsed_start is not None and parsed_end is not None:
+            # Both start and end provided
+            self._filters.append(
+                lambda f: f.period_end and parsed_start <= f.period_end <= parsed_end
+            )
+        elif parsed_start is not None:
+            # Only start provided - filter for dates >= start
+            self._filters.append(
+                lambda f: f.period_end and f.period_end >= parsed_start
+            )
+        else:
+            # Only end provided - filter for dates <= end
+            self._filters.append(
+                lambda f: f.period_end and f.period_end <= parsed_end
+            )
+        
         return self
     
     def as_of(self, as_of_date: date) -> 'FactQuery':
@@ -328,6 +413,95 @@ class FactQuery:
         )
         return self
     
+    # Enhanced filtering methods for structural metadata
+    def by_section(self, section: str) -> 'FactQuery':
+        """
+        Filter by statement section (e.g., 'Current Assets', 'Operating Activities').
+        
+        Args:
+            section: Section name to filter by
+            
+        Returns:
+            Self for method chaining
+        """
+        section_lower = section.lower()
+        self._filters.append(
+            lambda f: f.section and section_lower in f.section.lower()
+        )
+        return self
+    
+    def by_depth(self, max_depth: int) -> 'FactQuery':
+        """
+        Filter by hierarchy depth in statement.
+        
+        Args:
+            max_depth: Maximum depth to include
+            
+        Returns:
+            Self for method chaining
+        """
+        self._filters.append(
+            lambda f: f.depth is not None and f.depth <= max_depth
+        )
+        return self
+    
+    def totals_only(self) -> 'FactQuery':
+        """
+        Get only total/sum concepts.
+        
+        Returns:
+            Self for method chaining
+        """
+        self._filters.append(lambda f: f.is_total)
+        return self
+    
+    def concrete_only(self) -> 'FactQuery':
+        """
+        Exclude abstract/header concepts.
+        
+        Returns:
+            Self for method chaining
+        """
+        self._filters.append(lambda f: not f.is_abstract)
+        return self
+    
+    def abstracts_only(self) -> 'FactQuery':
+        """
+        Get only abstract/header concepts.
+        
+        Returns:
+            Self for method chaining
+        """
+        self._filters.append(lambda f: f.is_abstract)
+        return self
+    
+    def with_parent(self, parent_concept: str) -> 'FactQuery':
+        """
+        Filter by parent concept in hierarchy.
+        
+        Args:
+            parent_concept: Parent concept name
+            
+        Returns:
+            Self for method chaining
+        """
+        self._filters.append(
+            lambda f: f.parent_concept and parent_concept in f.parent_concept
+        )
+        return self
+    
+    def root_items_only(self) -> 'FactQuery':
+        """
+        Get only root level items (no parent).
+        
+        Returns:
+            Self for method chaining
+        """
+        self._filters.append(
+            lambda f: f.parent_concept is None or f.depth == 0
+        )
+        return self
+    
     # Sorting and limiting
     def sort_by(self, field: str, ascending: bool = True) -> 'FactQuery':
         """
@@ -389,6 +563,16 @@ class FactQuery:
         
         return results
     
+    def with_hierarchy(self) -> 'HierarchicalFactsResult':
+        """
+        Return facts organized hierarchically based on parent-child relationships.
+        
+        Returns:
+            HierarchicalFactsResult with tree structure
+        """
+        facts = self.execute()
+        return HierarchicalFactsResult(facts)
+    
     def to_dataframe(self, *columns) -> pd.DataFrame:
         """
         Convert results to pandas DataFrame.
@@ -765,12 +949,6 @@ class FactQuery:
         # Add rows
         for fact in display_facts:
             
-            # Format period
-            period = f"{fact.fiscal_period} {fact.fiscal_year}" if fact.fiscal_period and fact.fiscal_year else "N/A"
-            
-            # Format filing date
-            filed = fact.filing_date.strftime('%Y-%m-%d') if fact.filing_date else "N/A"
-            
             results_table.add_row(
                 fact.concept,
                 str(fact.value) if fact.value else "N/A",
@@ -836,4 +1014,135 @@ class FactQuery:
     def __repr__(self) -> str:
         """String representation using rich formatting."""
         from edgar.richtools import repr_rich
-        return repr_rich(self.__rich__())
\ No newline at end of file
+        return repr_rich(self.__rich__())
+
+
+class HierarchicalFactsResult:
+    """
+    Results organized in hierarchical tree structure.
+    
+    This class organizes facts based on parent-child relationships
+    to provide a tree view of the data.
+    """
+    
+    def __init__(self, facts: List[FinancialFact]):
+        """
+        Initialize with flat list of facts.
+        
+        Args:
+            facts: List of financial facts to organize
+        """
+        self.facts = facts
+        self._build_hierarchy()
+    
+    def _build_hierarchy(self):
+        """Build hierarchical structure from facts."""
+        # Create lookup maps
+        self.fact_map = {}
+        self.children_map = defaultdict(list)
+        self.roots = []
+        
+        # First pass: create map and identify relationships
+        for fact in self.facts:
+            concept = fact.concept.split(':')[-1] if ':' in fact.concept else fact.concept
+            self.fact_map[concept] = fact
+            
+            if fact.parent_concept:
+                self.children_map[fact.parent_concept].append(concept)
+            elif fact.depth == 0 or fact.depth is None:
+                self.roots.append(concept)
+    
+    def to_dict(self) -> Dict[str, Any]:
+        """Convert to nested dictionary structure."""
+        def build_node(concept: str) -> Dict[str, Any]:
+            fact = self.fact_map.get(concept)
+            if not fact:
+                return {'concept': concept, 'error': 'Fact not found'}
+            
+            node = {
+                'concept': concept,
+                'label': fact.label,
+                'value': fact.numeric_value,
+                'is_abstract': fact.is_abstract,
+                'is_total': fact.is_total,
+                'section': fact.section,
+                'depth': fact.depth
+            }
+            
+            # Add children
+            children = self.children_map.get(concept, [])
+            if children:
+                node['children'] = [build_node(child) for child in children]
+            
+            return node
+        
+        return {
+            'roots': [build_node(root) for root in self.roots],
+            'total_facts': len(self.facts)
+        }
+    
+    def to_dataframe(self, include_hierarchy: bool = True) -> pd.DataFrame:
+        """
+        Convert to DataFrame with optional hierarchy indicators.
+        
+        Args:
+            include_hierarchy: Whether to include hierarchy columns
+            
+        Returns:
+            DataFrame with facts and hierarchy info
+        """
+        records = []
+        
+        def process_node(concept: str, level: int = 0, parent: str = None):
+            fact = self.fact_map.get(concept)
+            if not fact:
+                return
+            
+            record = {
+                'concept': concept,
+                'label': fact.label,
+                'value': fact.numeric_value,
+                'unit': fact.unit,
+                'fiscal_year': fact.fiscal_year,
+                'fiscal_period': fact.fiscal_period
+            }
+            
+            if include_hierarchy:
+                record['level'] = level
+                record['parent'] = parent
+                record['is_abstract'] = fact.is_abstract
+                record['is_total'] = fact.is_total
+                record['section'] = fact.section
+            
+            records.append(record)
+            
+            # Process children
+            for child in self.children_map.get(concept, []):
+                process_node(child, level + 1, concept)
+        
+        # Process all roots
+        for root in self.roots:
+            process_node(root)
+        
+        # Add orphaned facts (not in hierarchy)
+        processed = set(r['concept'] for r in records)
+        for fact in self.facts:
+            concept = fact.concept.split(':')[-1] if ':' in fact.concept else fact.concept
+            if concept not in processed:
+                record = {
+                    'concept': concept,
+                    'label': fact.label,
+                    'value': fact.numeric_value,
+                    'unit': fact.unit,
+                    'fiscal_year': fact.fiscal_year,
+                    'fiscal_period': fact.fiscal_period
+                }
+                if include_hierarchy:
+                    record['level'] = 0
+                    record['parent'] = None
+                    record['is_abstract'] = fact.is_abstract
+                    record['is_total'] = fact.is_total
+                    record['section'] = fact.section
+                records.append(record)
+        
+        return pd.DataFrame(records) if records else pd.DataFrame()
\ No newline at end of file
