@@ -13,7 +13,8 @@ from rich.text import Text
 
 from edgar._party import Address, get_addresses_as_columns
 from edgar.richtools import repr_rich
-from edgar.core import sec_dot_gov, display_size
+from edgar.core import sec_dot_gov
+from edgar.formatting import display_size
 from edgar.httprequests import download_file
 from edgar.reference import describe_form
 
@@ -124,7 +125,7 @@ class Filer(BaseModel):
 
     def __rich__(self):
         contents = [self.company_data,
-                    get_addresses_as_columns(self.business_address, self.mail_address)
+                    get_addresses_as_columns(business_address=self.business_address, mailing_address=self.mail_address)
                     ]
 
         return Panel(Group(*contents), title="Filer", style="bold", box=box.ROUNDED)
@@ -142,7 +143,7 @@ class SubjectCompany(BaseModel):
 
     def __rich__(self):
         contents = [self.company_data,
-                    get_addresses_as_columns(self.business_address, self.mail_address)
+                    get_addresses_as_columns(business_address=self.business_address, mailing_address=self.mail_address)
                     ]
 
         return Panel(Group(*contents), title="Subject Company", style="bold", box=box.ROUNDED)
