@@ -3,25 +3,23 @@ import logging
 import os
 import shutil
 import tarfile
-import tempfile
-import time
-import uuid
 import zipfile
-from collections import deque
 from functools import wraps
 from io import BytesIO
 from pathlib import Path
-from threading import Lock
-from typing import Optional, Union
+from typing import Union, Optional
 
+import tempfile
+import uuid
 import orjson as json
+
 from httpx import AsyncClient, RequestError, Response, TimeoutException, ConnectError, HTTPError, Timeout, ReadTimeout
 import httpcore
 from stamina import retry
 from tqdm import tqdm
 
-from edgar.core import get_edgar_data_directory, text_extensions
-from edgar.httpclient import async_http_client, http_client
+from edgar.core import text_extensions, get_edgar_data_directory
+from edgar.httpclient import http_client, async_http_client
 
 """
 This module provides functions to handle HTTP requests with retry logic, throttling, and identity management.
@@ -41,10 +39,10 @@ __all__ = [
     "download_text_between_tags",
     "download_bulk_data",
     "download_datafile",
-    "throttle_requests",
 ]
 
 attempts = 6
+
 max_requests_per_second = 8
 throttle_disabled = False
 TIMEOUT = Timeout(30.0, connect=10.0)
@@ -82,123 +80,6 @@ class IdentityNotSetException(Exception):
     pass
 
 
-class RequestRate:
-    """
-    A simple class to represent a request rate, i.e., the maximum number of requests for a given time window
-    """
-
-    def __init__(self, max_requests: int, time_window: int):
-        if max_requests <= 0:
-            raise ValueError("max_requests must be a positive integer")
-        if time_window <= 0:
-            raise ValueError("time_window must be a positive integer")
-
-        self.max_requests: int = max_requests
-        self.time_window: int = time_window
-
-
-class Throttler:
-    """
-    A simple throttler that limits the number of requests per time window
-    """
-
-    def __init__(self, request_rate: RequestRate, sleep_interval=0.1):
-        self.request_rate = request_rate
-        self.sleep_interval = sleep_interval
-        self.request_timestamps = deque()
-        self.lock = Lock()
-        self.decorated_functions = None
-        self.total_calls = 0
-        self.peak_call_rate: float = 0.0
-
-    def get_ticket(self):
-        with self.lock:
-            current_time = time.monotonic()
-
-            # Remove timestamps older than the time window
-            while (
-                    self.request_timestamps
-                    and self.request_timestamps[0]
-                    <= current_time - self.request_rate.time_window
-            ):
-                self.request_timestamps.popleft()
-
-            if len(self.request_timestamps) < self.request_rate.max_requests:
-                self.request_timestamps.append(current_time)
-                return True
-            else:
-                return False
-
-    def wait_for_ticket(self):
-        while not self.get_ticket():
-            time.sleep(self.sleep_interval)
-
-    def update_metrics(self):
-        self.total_calls += 1
-        current_call_rate: float = (
-                len(self.request_timestamps) / self.request_rate.time_window
-        )
-        self.peak_call_rate = max(self.peak_call_rate, current_call_rate)
-
-    def get_metrics(self):
-        return {
-            "decorated_functions": self.decorated_functions,  # Now it's a list
-            "total_calls": self.total_calls,
-            "peak_call_rate": self.peak_call_rate,
-            "request_rate_limit": self.request_rate.max_requests,
-        }
-
-    def print_metrics(self):
-        metrics = self.get_metrics()
-        print(
-            f"Metrics for decorated functions: {', '.join(metrics['decorated_functions'])}"
-        )
-        print(f"Total calls: {metrics['total_calls']}")
-        print(f"Peak call rate: {metrics['peak_call_rate']:.2f} calls per second")
-
-
-_throttler_instances = {}  # Singleton instance for throttler
-
-
-def throttle_requests(request_rate=None, requests_per_second=None, **kwargs):
-    """
-    Decorator to throttle the number of requests per second.
-    """
-
-    if requests_per_second is not None:
-        request_rate = RequestRate(max_requests=requests_per_second, time_window=1)
-    elif request_rate is None:
-        raise ValueError("Either request_rate or requests_per_second must be provided")
-
-    # Use a single key for all instances to create a global throttler
-    key = "global_throttler"
-
-    if key not in _throttler_instances:
-        _throttler_instances[key] = Throttler(request_rate, **kwargs)
-
-    throttler = _throttler_instances[key]
-
-    def decorator(func):
-        @wraps(func)
-        def wrapper(*args, **kwargs):
-            if throttle_disabled:
-                return func(*args, **kwargs)
-            else:
-                throttler.wait_for_ticket()
-                result = func(*args, **kwargs)
-                throttler.update_metrics()
-                return result
-
-        # Store the decorated function name
-        if throttler.decorated_functions is None:
-            throttler.decorated_functions = []
-        throttler.decorated_functions.append(func.__name__)
-
-        return wrapper
-
-    return decorator
-
-
 def is_redirect(response):
     return response.status_code in [301, 302]
 
@@ -218,9 +99,7 @@ def with_identity(func):
         headers["User-Agent"] = identity
         kwargs["headers"] = headers
 
-        return func(
-            url, identity=identity, identity_callable=identity_callable, *args, **kwargs
-        )
+        return func(url, identity=identity, identity_callable=identity_callable, *args, **kwargs)
 
     return wrapper
 
@@ -240,14 +119,7 @@ def async_with_identity(func):
         headers["User-Agent"] = identity
         kwargs["headers"] = headers
 
-        return func(
-            client,
-            url,
-            identity=identity,
-            identity_callable=identity_callable,
-            *args,
-            **kwargs,
-        )
+        return func(client, url, identity=identity, identity_callable=identity_callable, *args, **kwargs)
 
     return wrapper
 
@@ -261,7 +133,6 @@ def async_with_identity(func):
     wait_exp_base=2
 )
 @with_identity
-@throttle_requests(requests_per_second=max_requests_per_second)
 def get_with_retry(url, identity=None, identity_callable=None, **kwargs):
     """
     Sends a GET request with retry functionality and identity handling.
@@ -283,15 +154,10 @@ def get_with_retry(url, identity=None, identity_callable=None, **kwargs):
         if response.status_code == 429:
             raise TooManyRequestsError(url)
         elif is_redirect(response):
-            return get_with_retry(
-                url=response.headers["Location"],
-                identity=identity,
-                identity_callable=identity_callable,
-                **kwargs,
-            )
+            return get_with_retry(url=response.headers["Location"], identity=identity, identity_callable=identity_callable, **kwargs)
         return response
 
-
+      
 @retry(
     on=RETRYABLE_EXCEPTIONS,
     attempts=QUICK_RETRY_ATTEMPTS,
@@ -301,10 +167,7 @@ def get_with_retry(url, identity=None, identity_callable=None, **kwargs):
     wait_exp_base=2
 )
 @async_with_identity
-@throttle_requests(requests_per_second=max_requests_per_second)
-async def get_with_retry_async(
-        client: AsyncClient, url, identity=None, identity_callable=None, **kwargs
-):
+async def get_with_retry_async(client: AsyncClient, url, identity=None, identity_callable=None, **kwargs):
     """
     Sends an asynchronous GET request with retry functionality and identity handling.
 
@@ -325,11 +188,7 @@ async def get_with_retry_async(
         raise TooManyRequestsError(url)
     elif is_redirect(response):
         return await get_with_retry_async(
-            client=client,
-            url=response.headers["Location"],
-            identity=identity,
-            identity_callable=identity_callable,
-            **kwargs,
+            client=client, url=response.headers["Location"], identity=identity, identity_callable=identity_callable, **kwargs
         )
     return response
 
@@ -344,7 +203,6 @@ async def get_with_retry_async(
     wait_exp_base=2
 )
 @with_identity
-@throttle_requests(requests_per_second=max_requests_per_second)
 def stream_with_retry(url, identity=None, identity_callable=None, **kwargs):
     """
     Sends a streaming GET request with retry functionality and identity handling.
@@ -366,12 +224,7 @@ def stream_with_retry(url, identity=None, identity_callable=None, **kwargs):
             if response.status_code == 429:
                 raise TooManyRequestsError(url)
             elif is_redirect(response):
-                response = stream_with_retry(
-                    response.headers["Location"],
-                    identity=identity,
-                    identity_callable=identity_callable,
-                    **kwargs,
-                )
+                response = stream_with_retry(response.headers["Location"], identity=identity, identity_callable=identity_callable, **kwargs)
                 yield from response
             else:
                 yield response
@@ -386,10 +239,7 @@ def stream_with_retry(url, identity=None, identity_callable=None, **kwargs):
     wait_exp_base=2
 )
 @with_identity
-@throttle_requests(requests_per_second=max_requests_per_second)
-def post_with_retry(
-        url, data=None, json=None, identity=None, identity_callable=None, **kwargs
-):
+def post_with_retry(url, data=None, json=None, identity=None, identity_callable=None, **kwargs):
     """
     Sends a POST request with retry functionality and identity handling.
 
@@ -413,12 +263,7 @@ def post_with_retry(
             raise TooManyRequestsError(url)
         elif is_redirect(response):
             return post_with_retry(
-                response.headers["Location"],
-                data=data,
-                json=json,
-                identity=identity,
-                identity_callable=identity_callable,
-                **kwargs,
+                response.headers["Location"], data=data, json=json, identity=identity, identity_callable=identity_callable, **kwargs
             )
         return response
 
@@ -432,16 +277,7 @@ def post_with_retry(
     wait_exp_base=2
 )
 @async_with_identity
-@throttle_requests(requests_per_second=max_requests_per_second)
-async def post_with_retry_async(
-        client: AsyncClient,
-        url,
-        data=None,
-        json=None,
-        identity=None,
-        identity_callable=None,
-        **kwargs,
-):
+async def post_with_retry_async(client: AsyncClient, url, data=None, json=None, identity=None, identity_callable=None, **kwargs):
     """
     Sends an asynchronous POST request with retry functionality and identity handling.
 
@@ -464,13 +300,7 @@ async def post_with_retry_async(
         raise TooManyRequestsError(url)
     elif is_redirect(response):
         return await post_with_retry_async(
-            client,
-            response.headers["Location"],
-            data=data,
-            json=json,
-            identity=identity,
-            identity_callable=identity_callable,
-            **kwargs,
+            client, response.headers["Location"], data=data, json=json, identity=identity, identity_callable=identity_callable, **kwargs
         )
     return response
 
@@ -493,9 +323,7 @@ def decode_content(content: bytes) -> str:
         return content.decode("latin-1")
 
 
-def save_or_return_content(
-        content: Union[str, bytes], path: Optional[Union[str, Path]]
-) -> Union[str, bytes, None]:
+def save_or_return_content(content: Union[str, bytes], path: Optional[Union[str, Path]]) -> Union[str, bytes, None]:
     """
     Save the content to a specified path or return the content.
 
@@ -527,9 +355,7 @@ def save_or_return_content(
     return content
 
 
-def download_file(
-        url: str, as_text: bool = None, path: Optional[Union[str, Path]] = None
-) -> Union[str, bytes, None]:
+def download_file(url: str, as_text: bool = None, path: Optional[Union[str, Path]] = None) -> Union[str, bytes, None]:
     """
     Download a file from a URL.
 
@@ -575,10 +401,7 @@ def download_file(
 
 
 async def download_file_async(
-        client: AsyncClient,
-        url: str,
-        as_text: bool = None,
-        path: Optional[Union[str, Path]] = None,
+    client: AsyncClient, url: str, as_text: bool = None, path: Optional[Union[str, Path]] = None
 ) -> Union[str, bytes, None]:
     """
     Download a file from a URL asynchronously.
@@ -616,11 +439,11 @@ async def download_file_async(
     return save_or_return_content(content, path)
 
 
-# Optimized chunk sizes for different file sizes
-CHUNK_SIZE_SMALL = 1 * 1024 * 1024      # 1MB for files < 100MB
-CHUNK_SIZE_MEDIUM = 8 * 1024 * 1024     # 8MB for files 100MB - 500MB  
-CHUNK_SIZE_LARGE = 32 * 1024 * 1024     # 32MB for files > 500MB
-CHUNK_SIZE_DEFAULT = 4 * 1024 * 1024    # 4MB default (backward compatibility)
+CHUNK_SIZE = 4 * 1024 * 1024  # 4MB
+CHUNK_SIZE_LARGE = 8 * 1024 * 1024  # 8MB for files > 500MB
+CHUNK_SIZE_MEDIUM = 4 * 1024 * 1024  # 4MB for files > 100MB
+CHUNK_SIZE_SMALL = 2 * 1024 * 1024  # 2MB for files <= 100MB
+CHUNK_SIZE_DEFAULT = CHUNK_SIZE
 
 
 @retry(
@@ -633,92 +456,89 @@ CHUNK_SIZE_DEFAULT = 4 * 1024 * 1024    # 4MB default (backward compatibility)
     wait_exp_base=2  # Exponential backoff (doubles delay each retry)
 )
 @with_identity
-@throttle_requests(requests_per_second=max_requests_per_second)
 async def stream_file(
-        url: str,
-        path: Optional[Union[str, Path]] = None,
-        client: Optional[AsyncClient] = None,
-        **kwargs,
+    url: str, as_text: bool = None, path: Optional[Union[str, Path]] = None, client: Optional[AsyncClient] = None, **kwargs
 ) -> Union[str, bytes, None]:
     """
     Download a file from a URL asynchronously with progress bar using httpx.
-    
-    Always streams to disk to avoid memory accumulation, then provides atomic 
-    file operations for reliability with large files.
 
     Args:
         url (str): The URL of the file to download.
-        as_text (bool, optional): Whether to return the file content as text or binary.
+        as_text (bool, optional): Whether to download the file as text or binary.
             If None, the default is determined based on the file extension. Defaults to None.
         path (str or Path, optional): The path where the file should be saved.
-            If None, returns the content instead of saving.
         client: The httpx.AsyncClient instance
 
     Returns:
-        str or bytes or None: The content of the downloaded file if path is None,
-        otherwise None after saving to path.
+        str or bytes: The content of the downloaded file, either as text or binary data.
     """
+    if as_text is None:
+        # Set the default based on the file extension
+        as_text = url.endswith(text_extensions)
 
     # Create temporary directory for atomic downloads
     temp_dir = tempfile.mkdtemp(prefix="edgar_")
     temp_file = Path(temp_dir) / f"download_{uuid.uuid1()}"
 
     try:
-        async with async_http_client(client, timeout=TIMEOUT) as async_client:
+        async with async_http_client(client, timeout=TIMEOUT, bypass_cache=True) as async_client:
             async with async_client.stream("GET", url) as response:
                 inspect_response(response)
                 total_size = int(response.headers.get("Content-Length", 0))
 
-                # Setup progress bar
-                total_mb = total_size / (1024 * 1024) if total_size > 0 else None
-                progress_bar = tqdm(
-                    total=total_mb,
-                    unit="MB",
-                    unit_scale=True,
-                    unit_divisor=1024,
-                    leave=False,
-                    position=0,
-                    dynamic_ncols=True,
-                    bar_format="{l_bar}{bar}| {n:.2f}/{total:.2f}MB [{elapsed}<{remaining}, {rate_fmt}]" if total_mb else "{desc}: {n:.2f}MB [{elapsed}, {rate_fmt}]",
-                    desc=f"Downloading {os.path.basename(url)}",
-                    ascii=False,
-                )
-
-                # Select optimal chunk size based on file size
-                if total_size > 0:
-                    if total_size > 500 * 1024 * 1024:  # > 500MB
-                        chunk_size = CHUNK_SIZE_LARGE
-                    elif total_size > 100 * 1024 * 1024:  # > 100MB
-                        chunk_size = CHUNK_SIZE_MEDIUM
-                    else:  # <= 100MB
-                        chunk_size = CHUNK_SIZE_SMALL
+                if as_text:
+                    # Download as text
+                    content = await response.text()
+                    return content
                 else:
-                    # Unknown size, use default
-                    chunk_size = CHUNK_SIZE_DEFAULT
+                    # Download as binary - select optimal chunk size first
+                    if total_size > 0:
+                        if total_size > 500 * 1024 * 1024:  # > 500MB
+                            chunk_size = CHUNK_SIZE_LARGE
+                        elif total_size > 100 * 1024 * 1024:  # > 100MB
+                            chunk_size = CHUNK_SIZE_MEDIUM
+                        else:  # <= 100MB
+                            chunk_size = CHUNK_SIZE_SMALL
+                    else:
+                        # Unknown size, use default
+                        chunk_size = CHUNK_SIZE_DEFAULT
 
-                # Always stream to temporary file
-                try:
-                    with open(temp_file, "wb") as f:
-                        # For large files, update progress less frequently to reduce overhead
-                        update_threshold = 1.0 if total_size > 500 * 1024 * 1024 else 0.1  # MB
-                        accumulated_mb = 0.0
-                        
-                        async for chunk in response.aiter_bytes(chunk_size=chunk_size):
-                            f.write(chunk)
-                            chunk_mb = len(chunk) / (1024 * 1024)
-                            accumulated_mb += chunk_mb
+                    progress_bar = tqdm(
+                        total=total_size / (1024 * 1024),
+                        unit="MB",
+                        unit_scale=True,
+                        unit_divisor=1024,
+                        leave=False,  # Force horizontal display
+                        position=0,  # Lock the position
+                        dynamic_ncols=True,  # Adapt to terminal width
+                        bar_format="{l_bar}{bar}| {n:.2f}/{total:.2f}MB [{elapsed}<{remaining}, {rate_fmt}]",
+                        desc=f"Downloading {os.path.basename(url)}",
+                        ascii=False,
+                    )
+
+                    # Always stream to temporary file
+                    try:
+                        with open(temp_file, "wb") as f:
+                            # For large files, update progress less frequently to reduce overhead
+                            update_threshold = 1.0 if total_size > 500 * 1024 * 1024 else 0.1  # MB
+                            accumulated_mb = 0.0
                             
-                            # Update progress bar only when threshold is reached
-                            if accumulated_mb >= update_threshold:
+                            async for chunk in response.aiter_bytes(chunk_size=chunk_size):
+                                f.write(chunk)
+                                chunk_mb = len(chunk) / (1024 * 1024)
+                                accumulated_mb += chunk_mb
+                                
+                                # Update progress bar only when threshold is reached
+                                if accumulated_mb >= update_threshold:
+                                    progress_bar.update(accumulated_mb)
+                                    accumulated_mb = 0.0
+                            
+                            # Update any remaining progress
+                            if accumulated_mb > 0:
                                 progress_bar.update(accumulated_mb)
-                                accumulated_mb = 0.0
-                        
-                        # Update any remaining progress
-                        if accumulated_mb > 0:
-                            progress_bar.update(accumulated_mb)
 
-                finally:
-                    progress_bar.close()
+                    finally:
+                        progress_bar.close()
 
                 # Handle the result based on whether path was provided
                 if path is not None:
@@ -806,9 +626,7 @@ def download_text_between_tags(url: str, tag: str):
 
                 # If within header lines, add to header_content
                 elif is_header:
-                    content += (
-                            line + "\n"
-                    )  # Add a newline to preserve original line breaks
+                    content += line + "\n"  # Add a newline to preserve original line breaks
     return content
 
 
@@ -861,7 +679,7 @@ async def download_bulk_data(
         # Create the directory with parents=True and exist_ok=True to avoid race conditions
         download_path.mkdir(parents=True, exist_ok=True)
 
-        # Download the file (don't decompress archives)
+        # Download the file
         try:
             await stream_file(url, client=client, path=download_path)
         except Exception as e:
@@ -875,9 +693,7 @@ async def download_bulk_data(
                     total_size = sum(info.file_size for info in z.filelist)
                     extracted_size = 0
 
-                    with tqdm(
-                            total=total_size, unit="B", unit_scale=True, desc="Extracting"
-                    ) as pbar:
+                    with tqdm(total=total_size, unit="B", unit_scale=True, desc="Extracting") as pbar:
                         for info in z.filelist:
                             z.extract(info, download_path)
                             extracted_size += info.file_size
@@ -888,27 +704,19 @@ async def download_bulk_data(
                     # Security check for tar files to prevent path traversal
                     def is_within_directory(directory: Path, target: Path) -> bool:
                         try:
-                            return os.path.commonpath([directory, target]) == str(
-                                directory
-                            )
+                            return os.path.commonpath([directory, target]) == str(directory)
                         except ValueError:
                             return False
 
                     members = tar.getmembers()
                     total_size = sum(member.size for member in members)
 
-                    with tqdm(
-                            total=total_size, unit="B", unit_scale=True, desc="Extracting"
-                    ) as pbar:
+                    with tqdm(total=total_size, unit="B", unit_scale=True, desc="Extracting") as pbar:
                         for member in members:
                             # Check for path traversal
                             member_path = os.path.join(str(download_path), member.name)
-                            if not is_within_directory(
-                                    Path(str(download_path)), Path(member_path)
-                            ):
-                                raise ValueError(
-                                    f"Attempted path traversal in tar file: {member.name}"
-                                )
+                            if not is_within_directory(Path(str(download_path)), Path(member_path)):
+                                raise ValueError(f"Attempted path traversal in tar file: {member.name}")
 
                             # Extract file and update progress
                             tar.extract(member, str(download_path))
@@ -925,9 +733,7 @@ async def download_bulk_data(
                 if download_filename.exists():
                     download_filename.unlink()
             except Exception as e:
-                logger.warning(
-                    f"Failed to delete archive file {download_filename}: {e}"
-                )
+                logger.warning(f"Failed to delete archive file {download_filename}: {e}")
 
         return download_path
 
