@@ -1,4 +1,4 @@
 from edgar.sgml.sgml_common import FilingSGML, iter_documents, list_documents
 from edgar.sgml.sgml_parser import SGMLDocument
-from edgar.sgml.sgml_header import FilingHeader, Filer
+from edgar.sgml.sgml_header import FilingHeader, Filer, Issuer, ReportingOwner, FilingMetadata
 from edgar.sgml.filing_summary import FilingSummary, Reports, Report, Statements
\ No newline at end of file
