@@ -1573,9 +1573,13 @@ class XBRLParser:
 
         This method handles the application of negative weights from calculation arcs.
         Per XBRL specification, a negative weight should flip the sign of a fact value
-        when used in calculations. This is particularly common with elements like
-        "IncreaseDecreaseInInventories" which should be negated when contributing
-        to cash flow calculations.
+        when used in calculations.
+        
+        However, for certain expense concepts that should be consistently positive across
+        companies (e.g., R&D expenses), we preserve the original values to ensure 
+        consistency with the SEC CompanyFacts API and proper cross-company comparisons.
+        
+        This addresses issue #334: Inconsistent signs for R&D expenses across companies.
         """
         try:
             # Create a mapping of normalized element IDs to their calculation nodes
@@ -1588,8 +1592,97 @@ class XBRLParser:
                     normalized_element_id = element_id.replace(':', '_') if ':' in element_id else element_id
                     element_to_calc_node[normalized_element_id] = node
 
+            # Concepts that should remain consistently positive across companies
+            # These are expense concepts that represent costs/spending amounts
+            consistent_positive_concepts = {
+                # Research and Development Expenses
+                'us-gaap_ResearchAndDevelopmentExpense',
+                'us_gaap_ResearchAndDevelopmentExpense', 
+                'ResearchAndDevelopmentExpense',
+                
+                # Selling, General & Administrative Expenses
+                'us-gaap_SellingGeneralAndAdministrativeExpense',
+                'us_gaap_SellingGeneralAndAdministrativeExpense',
+                'SellingGeneralAndAdministrativeExpense',
+                
+                # General and Administrative Expenses (separate from SG&A)
+                'us-gaap_GeneralAndAdministrativeExpense',
+                'us_gaap_GeneralAndAdministrativeExpense',
+                'GeneralAndAdministrativeExpense',
+                
+                # Selling Expenses
+                'us-gaap_SellingExpense',
+                'us_gaap_SellingExpense',
+                'SellingExpense',
+                
+                # Marketing and Advertising Expenses
+                'us-gaap_SellingAndMarketingExpense',
+                'us_gaap_SellingAndMarketingExpense',
+                'SellingAndMarketingExpense',
+                'us-gaap_MarketingExpense',
+                'us_gaap_MarketingExpense',
+                'MarketingExpense',
+                'us-gaap_AdvertisingExpense',
+                'us_gaap_AdvertisingExpense',
+                'AdvertisingExpense',
+                
+                # Share-based Compensation Expenses
+                'us-gaap_AllocatedShareBasedCompensationExpense',
+                'us_gaap_AllocatedShareBasedCompensationExpense',
+                'AllocatedShareBasedCompensationExpense',
+                'us-gaap_ShareBasedCompensationArrangementByShareBasedPaymentAwardExpenseRecognized',
+                'us_gaap_ShareBasedCompensationArrangementByShareBasedPaymentAwardExpenseRecognized',
+                'ShareBasedCompensationArrangementByShareBasedPaymentAwardExpenseRecognized',
+                
+                # Operating Expenses (general)
+                'us-gaap_OperatingExpenses',
+                'us_gaap_OperatingExpenses',
+                'OperatingExpenses',
+                
+                # Professional Services Expenses
+                'us-gaap_ProfessionalServiceFees',
+                'us_gaap_ProfessionalServiceFees',
+                'ProfessionalServiceFees',
+                
+                # Compensation and Benefits
+                'us-gaap_LaborAndRelatedExpense',
+                'us_gaap_LaborAndRelatedExpense',
+                'LaborAndRelatedExpense',
+                'us-gaap_EmployeeBenefitsExpense',
+                'us_gaap_EmployeeBenefitsExpense',
+                'EmployeeBenefitsExpense'
+            }
+            
+            # Concepts that can legitimately be negative (benefits, credits, reversals)
+            # These should NOT be forced positive even if they have negative calculation weights
+            legitimate_negative_concepts = {
+                # Tax benefits and credits
+                'us-gaap_IncomeTaxExpenseBenefit',
+                'us_gaap_IncomeTaxExpenseBenefit',
+                'IncomeTaxExpenseBenefit',
+                'us-gaap_IncomeTaxRecoveryExpense',
+                'us_gaap_IncomeTaxRecoveryExpense',
+                'IncomeTaxRecoveryExpense',
+                
+                # Interest expense/income that can be net negative
+                'us-gaap_InterestIncomeExpenseNet',
+                'us_gaap_InterestIncomeExpenseNet',
+                'InterestIncomeExpenseNet',
+                
+                # Foreign exchange gains/losses
+                'us-gaap_ForeignCurrencyTransactionGainLossBeforeTax',
+                'us_gaap_ForeignCurrencyTransactionGainLossBeforeTax',
+                'ForeignCurrencyTransactionGainLossBeforeTax',
+                
+                # Restructuring reversals/credits
+                'us-gaap_RestructuringChargesAndReversals',
+                'us_gaap_RestructuringChargesAndReversals',
+                'RestructuringChargesAndReversals'
+            }
+
             # Apply calculation weights to facts
             adjusted_count = 0
+            preserved_count = 0
 
             # Find and adjust facts with negative weights
             for fact_key, fact in list(self.facts.items()):
@@ -1602,6 +1695,18 @@ class XBRLParser:
 
                 # Apply negative weights if found
                 if calc_node and calc_node.weight < 0:
+                    # Check if this is a concept that can legitimately be negative
+                    if normalized_element_id in legitimate_negative_concepts:
+                        # Allow normal calculation weight processing for legitimate negatives
+                        pass
+                    # Check if this is a concept that should remain consistently positive
+                    elif normalized_element_id in consistent_positive_concepts:
+                        # Preserve the original positive value for consistency
+                        preserved_count += 1
+                        log.debug(f"Preserved positive value for {fact.element_id}: {fact.numeric_value} "
+                                f"(ignoring calculation weight {calc_node.weight})")
+                        continue
+                        
                     if fact.numeric_value is not None:
                         # Store original for logging
                         original_value = fact.numeric_value
@@ -1624,7 +1729,7 @@ class XBRLParser:
 
                         log.debug(f"Adjusted fact {fact.element_id}: {original_value} -> {fact.numeric_value}")
 
-            log.debug(f"Applied calculation weights to {adjusted_count} facts")
+            log.debug(f"Applied calculation weights to {adjusted_count} facts, preserved {preserved_count} facts")
 
         except Exception as e:
             # Log the error but don't fail the entire parsing process
